# @hidoo/gulp-task-build-js-browserify

> Task that build javascript by browserify for gulp.

## Installation

```sh
$ npm install --save-dev gulp@next @babel/{core,polyfill,preset-env} @hidoo/gulp-task-build-js-browserify
```

## Usage

```js
import {task} from 'gulp';
import buildJs from '@hidoo/gulp-task-build-js-browserify';

task('js', buildJs({
  src: '/path/to/js/main.js',
  dest: '/path/to/dest'
}));
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### buildJs

return javascript build task by browserify

#### Parameters

-   `options` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** options (optional, default `{}`)
    -   `options.name` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** task name (use as displayName) (optional, default `'build:js'`)
    -   `options.src` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** source path
    -   `options.dest` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination path
    -   `options.filename` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination filename (optional, default `'main.js'`)
    -   `options.suffix` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** suffix when compressed (optional, default `'.min'`)
    -   `options.browsers` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)&lt;[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>?** target browsers.
          see: [default target browsers](http://browserl.ist/?q=%3E+0.5%25+in+JP%2C+ie%3E%3D+10%2C+android+%3E%3D+4.4)
    -   `options.useBuiltIns` **([String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String) \| [Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean))** use polyfill or not.
          see: [useBuiltIns in @babel/preset-env](https://babeljs.io/docs/en/babel-preset-env#usebuiltins) (optional, default `'usage'`)
    -   `options.corejs` **([Number](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number) \| [String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String) \| [Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object))** specify core-js version (Recommend setting with options.useBuiltIns: 'entry')
          see: [corejs in @babel/preset-env](https://github.com/zloirock/core-js#babelpreset-env) (optional, default `2`)
    -   `options.babelrc` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** babelrc path (optional, default `path.resolve(process.cwd(),'.babelrc.js')`)
    -   `options.compress` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** compress file or not (optional, default `false`)
    -   `options.verbose` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** out log or not (optional, default `false`)

#### Examples

```javascript
import {task} from 'gulp';
import buildJs from '@hidoo/gulp-task-build-js-browserify';

task('js', buildJs({
  name: 'js:main',
  src: '/path/to/js/main.js',
  dest: '/path/to/dest'
  filename: 'main.js',
  suffix: '.hoge',
  browsers: ['> 0.1% in JP'],
  useBuiltIns: false,
  corejs: 3,
  babelrc: '/path/to/.babelrc.js',
  compress: true,
  verbose: true
}));
```

Returns **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)&lt;[Stream](https://nodejs.org/api/stream.html)>** 

## Test

```sh
$ npm test
```

## License

MIT
